==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Clicca sulla Tray
o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Registrazione</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Cattura schermo</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Salvataggio fallito, è consigliato salvare il file nella Home.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Screenshot terminato</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>seleziona-area</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Salvato in %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Appunti</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Salvataggio della registrazione, attendere...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Poiché l&apos;effetto finestra è disabilitato durante il processo, la registrazione deve essere interrotta</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Registrazione completata</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Salvato in %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Registrazione</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Deepin Screenshot si avvierà dopo %1 secondi</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Inserisci qui il testo</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Avvia/Istantanea</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Esci/Salva</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Disegno</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Aggiusta dimensioni</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Avvio rapido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Cattura finestra</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Istantanea ritardata</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Istantanea schermo intero</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rettangolo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumenta limite superiore</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumenta limite inferiore</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumenta limite sinistro</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumenta limite destro</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Diminuisci limite superiore</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Diminuisci limite inferiore</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Diminuisci limite sinistro</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Diminuisci limite destro</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visualizza scorciatoie</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Suono</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Sequenza tasti</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Inizia la registrazione</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Avvia/Registra</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Sfocato</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaico</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Suono attivo</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfono</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Audio di Sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Suoto disattivato</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Mostra la sequenza dei tasti</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Nascondi sequenza dei tasti</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam attiva</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam disattivata</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Mostra click</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rettangolo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Freccia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Salva in</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Cartella</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Appunti</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostra il puntatore</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mostra il puntatore</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Sistema l&apos;area di registrazione tra %1*%2 per i migliori effetti video</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Registrazioni</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Clicca sulla Tray
o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Non ruotare lo schermo durante la registrazione</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Registrazione</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Cattura schermo</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Salvataggio fallito, è consigliato salvare il file nella Home.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Screenshot terminato</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>seleziona-area</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Salvato in %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Appunti</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Salvataggio della registrazione, attendere...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Poiché l&apos;effetto finestra è disabilitato durante il processo, la registrazione deve essere interrotta</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>Lo screenshot è stato salvato nell&apos;album</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Screenshot fallito.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Screenshot a scorrimento</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Registrazione completata</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Salvato in %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Registrazione</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Deepin Screenshot si avvierà dopo %1 secondi</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Chiedi aiuto.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Acquisizione screenshot a scorrimento fallita</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Raggiunto il fondo dell&apos;area di scorrimento</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Raggiunto la lunghezza massima</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>Regola l&apos;area da catturare</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Scorri la rotellina del mouse o fai clic per acquisire uno screenshot a scorrimento</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Rallenta la velocità di scorrimento</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Area non valida, clicca su </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Inserisci qui il testo</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Avvia/Istantanea</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Esci/Salva</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Aggiusta dimensioni</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Avvio rapido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Cattura finestra</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Istantanea ritardata</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Istantanea schermo intero</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rettangolo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumenta limite superiore</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumenta limite inferiore</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumenta limite sinistro</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumenta limite destro</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Diminuisci limite superiore</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Diminuisci limite inferiore</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Diminuisci limite sinistro</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Diminuisci limite destro</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visualizza scorciatoie</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Suono</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Sequenza tasti</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Inizia la registrazione</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Avvia/Registra</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Estrai testo</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Screenshot a scorrimento</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Sfocato</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaico</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Suono attivo</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfono</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Audio di Sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Suoto disattivato</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Mostra la sequenza dei tasti</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Nascondi sequenza dei tasti</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam attiva</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam disattivata</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Mostra click</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rettangolo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Freccia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Salva in</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Cartella</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Appunti</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostra il puntatore</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mostra il puntatore</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Estrai testo</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Screenshot a scorrimento</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Sistema l&apos;area di registrazione tra %1*%2 per i migliori effetti video</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>La registrazione dello schermo non è supportata al momento</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
</context>
</TS>
